Brazil World Cup protests: Striking images of the country’s anti-World Cup movement.
Author: https://www.facebook.com/jjphotojou,https://www.facebook.com/JeremyDStahl
Description: The biggest challenge to Brazil’s World Cup preparations over the past few weeks has been the chaos caused by striking public workers. While São Paulo subway workers voted to at least temporarily suspend their strikes on Monday night, protests by activists angry at the money being spent by Brazil to...
Keywords: Brazil protests, Rio protests, Sau Paulo protests, World Cup protests, World Cup strikes, strikes, Brazil strikes, Sau Paulo strikes, Brazil subway strikes, Sau Paulo, Rio World Cup

Slate
The Spot
Slate's soccer blog.
June 10 2014 5:21 PM

#
Striking Images of Brazil’s Anti-World Cup Protest Movement

##

By Juliana Jiménez Jaramillo and Jeremy Stahl

The biggest challenge to Brazil’s World Cup preparations over the past few weeks has been the chaos caused by striking public workers. While São Paulo subway workers voted to at least temporarily suspend their strikes on Monday night, protests by activists angry at the money being spent by Brazil to host the event are expected to continue throughout the World Cup.

Though nowhere near the size of last year’s broad-based social movement, which brought millions to the streets, protests have been building back up in recent months. The tournament, which begins Thursday in São Paulo, has reportedly cost in excess of $11 billion, money protesters say could have been spent on public infrastructure. The movement has already produced its share of powerful images. Here are some of the most striking photos.

Demonstrators from the anarchist group Black Bloc clash with police inSão Paulo during a protest against the World Cup on June 12, 2014, the opening day of the event.

Photo by Victor Moriyama/Getty Images

Police take up positions during a World Cup protest outside Carrao Metro Station on June 12, 2014 in São Paulo.

Photo by Mario Tama/Getty Images

A journalist is taken from a protest on a stretcher outside Carrao Metro Station on June 12, 2014 in São Paulo.

Photo by Mario Tama/Getty Images

A journalist is carried after being injured during a World Cup protest in São Paulo on June 12, 2014.

Photo by Victor Moriyama/Getty Images

Police officers clash with supporters of the native Indian community during a protest outside the Indian museum, next to the Maracanã stadium, in Rio de Janeiro, Dec. 16, 2013. Police arrested more than 20 indigenous people who occupied the abandoned museum to protest its demolition as part of renovations ahead of the World Cup.

Photo by Pilar Olivares/Reuters

Demonstrators clash with military police officers spraying tear gas during a protest in São Paulo on April 29, 2014. An estimated 1,500 protesters gathered for a march against the costs associated with Brazil's hosting of the World Cup.

Photo by Nacho Doce/Reuters

A member of Brazil's Homeless Workers' Movement blocks the Octavio Frias de Oliveira Bridge during a protest against the World Cup in São Paulo on May 22, 2014.

Photo by Nacho Doce/Reuters

Police officers search for demonstrators during the "International Day of World Cup Resistance" in São Paulo on May 15, 2014.

Photo by Nelson Almedia/AFP/Getty Images

Protesters clash with police officers during an anti-World Cup protest on May 15, 2014, in São Paulo.

Photo by Victor Moriyama/Getty Images

About 25,000 members of the Homeless Workers' Movement held large demonstrations to claim their right to housing on May 22, 2014, in São Paulo. They question government spending for the construction of stadiums for the World Cup.

Photo by Victor Moriyama/Getty Images

A young protester stands in front of police guarding a government building at a demonstration against the new increase in public bus fares on Feb. 10, 2014 in Rio de Janeiro. Widespread protests began in the country last June following a different bus fare increase in São Paulo.

Photo by Mario Tama/Getty Images

Demonstrators attack a Bradesco bank branch during a protest against the World Cup inSão Paulo on Jan. 25, 2014.

Photo by Nacho Doce/Reuters

Police officers hit a demonstrator during a protest against the government's expenditure for the World Cup in São Paulo on Feb. 22, 2014.

Photo by Nelson Almedia/AFP/Getty Images

Members of the Homeless Workers' Movement hold demonstrations in São Paulo.

Photo by Victor Moriyama/Getty Images

Police officers stand guard as demonstrators march in São Paulo on March 13, 2014.

Photo by Nelson Almedia/AFP/Getty Images

A member of the Homeless Workers' Movement waves a flag on May 22, 2014 in São Paulo.

Photo by Victor Moriyama/Getty Images

Indigenous Indians dance as they attend a protest against the Indian policy of President Dilma Rousseff's government and the costs of the 2014 World Cup in front of the Brazilian congress in Brasilia, May 28, 2014.

Photo by Joedson Alves/Reuters

Brazilian natives from different ethnic groups block the entrance of the Ministry of Justice during a protest as part of Indigenous Mobilization Week, in Brasilia on May 29, 2014.

Photo by Evaristo Sa/AFP/Getty Images

A boy holds a soccer ball, with red tape on it the shape of cross in front of a Brazilian flag at Santa Luzia slum in Brasilia, May 30, 2014.

Photo by Joedson Alves/Reuters

Powered by Livefyre
News & Politics
Politics
Jan. 2 2015 8:53 PM What Matters in Selma Critics say Ava DuVernay’s film isn’t fair to LBJ. That’s because it’s about a movement, not leaders. Jamelle Bouie
Chinese Presidents Never Show Off Their Human Sides. Why Is Xi?
Behind the Scenes of Australia’s Prostitution Boom
Palestinians Continue to Pursue Statehood. Israel Continues to Rely on the U.S. to Stop Them.
Some of the Most Striking Images and Memorable Events of the Year
Why I Am Optimistic About the Future of Race Relations in America
Did Rep. Steve Scalise Admit to Speaking at a White Supremacist Event He Never Attended?
Business
Moneybox
Jan. 2 2015 4:29 PM The Subtle Typographical Art of a Chicken McNugget Poster Jordan Weissmann
My Favorite Graph of 2014: The Rise and Rise of the Top 0.1 Percent
These Are the Countries That Will Rage the Most on New Year’s Eve
New Year’s Eve Is the Best and the Worst Day of the Year for Uber
Orbitz and United Are Suing a 22-Year-Old Who Figured Out How to Game Airlines
Google and Microsoft Side With Travelers Who Want to Use Their Wi-Fi Hot Spots in Hotels
Dunkin’ Donuts Has Huge Expansion Plans
Life
Family
Jan. 2 2015 5:09 PM Parenting With Chronic Pain What kind of mother refuses to pick up her child? This kind. Sarah Erdreich
Florida Clerks Cancel All Courthouse Weddings to Avoid Performing Gay Ceremonies
Prosecuting Leelah Alcorn’s Parents Won’t Help Isolated, Bullied Trans Kids
These Japanese Rocks Have Been United in Marriage
Law Firm Issues Bogus Advice to Clerks About Gay Marriage Licenses, Gets Slapped Down
Are Gay People Capable of Platonic Friendship?
Do Soldiers in Combat Really Yell and Scream Like in Movies?
Double X
The XX Factor
Jan. 2 2015 12:43 PM Mario Cuomo Made the Case for Catholics to Be Pro-Choice Amanda Marcotte
FSU's Rose Bowl Loss Was Not a Victory for Rape Victims
Fed Chair Janet Yellen Didn't Make the Economist’s Influential Economists List. Only Men Did.
2014 Was a Great Year for Feminism. Is a Backlash Coming?
The Best Things Written About Women This Year
Nashville Police Chief Who Respects Protesters Also Fights for Victims of Domestic Violence
Gov. Bob McDonnell’s Daughters Carry on a Family Tradition: To Save Dad, Blame Mom
Slate Plus
Behind the Scenes
Dec. 31 2014 1:16 PM Slate Staffers Pick Their Out-of-Left-Field Favorite Slate Articles of 2014 Staffers pick their left-field favorite Slate articles of the year. Allison Benedikt, Jamelle Bouie, David Haglund, Laura Helmuth, Dan Kois, Joshua Keating, Chris Kirk, Miriam Krule, Dahlia Lithwick, and Katy Waldman
Slate’s Dana Stevens Watched 150 Movies This Year. Here’s How She Picked Her Top 10.
18 Years of Slate’s Best #WarOnChristmas Coverage
Why I Love My Christmas Birthday (Audio)
This Is What the Culture Gabfest Sounds Like Without Any Editing
Arts
Brow Beat
Jan. 2 2015 3:48 PM Did the Jay Wilds Interview Change Our Perspective on Serial? A Bonus Spoiler Special. David Haglund and Katy Waldman
Kanye West’s New Song With Paul McCartney Is a Beautiful Ode to His Late Mother
When Looking at the Tourists Is Part of the View
A Most Violent Year Sure Looks Like The Godfather, but Something’s Missing
This Spamalot-Like Musical Comedy Is the Oddest New TV Show in Years
The Rust Belt Theory of Low-Cost High Culture
In Part 3 of His Interview, Jay From Serial Chastises Reddit and Sarah Koenig
Technology
Future Tense
Dec. 31 2014 5:43 PM Now There's an App For Detecting Government Stingray Cell Phone Trackers Lily Hay Newman
Android Still Dominates, But People Sure Love Gifting iPhones
Scientists Are Trying to Figure Out Why Rosetta’s Comet Is Shaped Like a Duck
Pretty Much Every Smart Home Device You Can Think of Has Been Hacked
New Year’s Eve Snowstorm Set to Paralyze…Las Vegas?
Everyone Was Talking About Ferguson on Social Media This Year
I Still Use an AOL Email Account, and I’m (Mostly) Proud of It
Health & Science
Science
Jan. 2 2015 11:05 AM Surprise! The most important skill in science or self-improvement is noticing the unexpected. Julia Galef
An Icy Volcano and the Cosmic Cycle of Life
The Beauty of a Grain of Sand on the Cosmic Beach
Five Data-Driven Tips for Successful New Year’s Resolutions
Drunk Zebra Finches Slur Their Songs
The BA Blog Year That Was
Is It Crazy to Love a Dog the Way You Love a Child?
Sports
Sports Nut
Dec. 30 2014 7:08 AM The Internet’s Favorite Exercise Is the box jump a worthwhile training technique or just a fancy party trick? Alan Siegel
Can Topps Save Itself With Baseball Cards That Live Inside Your Phone?
Who’s the Best NBA Analogue for Every President? (Ronald Reagan Is Kobe Bryant.)
Sports Fans, Rejoice—the International Olympic Committee Just Reversed Its Dumbest Decision
ESPN Doesn't Do More Great Journalism Because Its Viewers Don’t Want It To
Florida State Football Fans Are the New Gamergate
Johnny Manziel Is Polarizing Even in the Town Where He Learned to Play Football